updated for mbed-os 5.5

Fork of Task121 by Nicholas Outram

Revision:
11:d7337ffe7f85
Parent:
9:5ac40ff61514
Child:
12:991c54e21f5f
--- a/main.cpp	Thu Jul 16 08:39:50 2020 +0000
+++ b/main.cpp	Thu Jul 16 09:47:03 2020 +0100
@@ -6,8 +6,8 @@
 #include "mbed.h"
 
 //Create a DigitalOut “object” called myled
-//Pass constant D7 as a “parameter”
-DigitalOut myled(D7);
+//Pass constant LED1 as a “parameter”
+DigitalOut myled(LED1);
 
 //The main function - all executable C / C++
 //applications have a main function. This is